# Event Dispatchers

A set of classes for dispatching events, they can be imported from `fluid.utils.dispatcher`:

```python
from fluid.utils.dispatcher import Dispatcher
```

::: fluid.utils.dispatcher.Event

::: fluid.utils.dispatcher.BaseDispatcher

::: fluid.utils.dispatcher.Dispatcher

::: fluid.utils.dispatcher.AsyncDispatcher
